@@ -31,8 +31,8 @@ class AimServerSettingsWidget : public AbstractAccountParametersWidget
 
 public:
     explicit AimServerSettingsWidget(ParameterEditModel *model,
-                                       QWidget *parent = 0);
-    virtual ~AimServerSettingsWidget();
+                                       QWidget *parent = nullptr);
+    ~AimServerSettingsWidget() override;
 
 private:
     Q_DISABLE_COPY(AimServerSettingsWidget)
